: This script is written specific to redhat, this needs more 
#generic to support other platforms when cee is suppored in other platforms

RELEASE_INFO_FILE=/etc/redhat-release
REQ_PKGS_LIST=./req_pkg.list
pname=`basename $0`
VERSION=4.1.2


CURRENT_DIR=`pwd`

#
# Variables which hold locations of applications
#
CLEAR=/usr/bin/clear
TAR=/bin/tar
IS_SANITY_OK=yes

usage()
{
    cat <<EOF
Usage: $pname [OPTION]

Known values for OPTION are:
  --version           display the version of this script
  --help              display this help and exit
EOF
}

main()
{
    check_ports;
#    check_req_pkgs;
    check_disk;
    check_os;
    if [ "$IS_SANITY_OK" != "yes" ] ; then
        echo >&2
        echo "WARNING : One of the sanity checks failed. This may cause a problem when installing CEE." >&2
        echo >&2
        echo "You can proceed with the installation. If a problem arises, please contact CollabNet technical support." >&2
        exit 2
    fi
}

check_os()
{

    if [ ! -f "$RELEASE_INFO_FILE" ]; then
        echo $RELEASE_INFO_FILE
        echo >&2
        echo "This installation is not supported in this operating system as of now" >&2
#        echo "contact technical support." >&2
        echo >&2
        IS_SANITY_OK=no
    else
        #Check if the OS is the suitable for CEE
        OS_RESULT=`grep "Red Hat Enterprise Linux ES release 3" "$RELEASE_INFO_FILE"`
        if [ "$OS_RESULT" = "" ] ; then
            echo >&2
            echo "This installation is not supported in this operating system as of now" >&2
#            echo "contact technical support." >&2
            echo >&2
            IS_SANITY_OK=no
            exit 1
        else
            echo "OS Check: OK"
        fi
    fi
}


check_req_pkgs(){

    RPM_REQUIRED_MAJOR=4
    RPM_REQUIRED_MINOR=2
    RPM_REQUIRED_PATCH=3

    RPM_CMD=`which rpm 2> /dev/null `
    RPM_RESULT=`echo $RPM_CMD | cut -f 1 -d ' ' `
    if [ "$RPM_RESULT" = "" -o "$RPM_RESULT" = "no" ] ; then
            echo >&2
            echo "This installation is not supported as RPM, is missing. You may have to choose" >&2
            echo "everything during the RHEL installation process to avoid this problem." >&2
#            echo "contact technical support." >&2
            echo >&2
            IS_SANITY_OK=no
            exit 1
   else

            # find the RPM version 
            RPM_VERSION_STRING=`$RPM_RESULT  --version| cut -f 3 -d ' ' `
            RPM_MAJOR_STRING=`echo $RPM_VERSION_STRING | cut -f 1 -d '.' `
            RPM_MAJOR_STRING=`echo $RPM_VERSION_STRING | cut -f 1 -d '.' `
            RPM_MINOR_STRING=`echo $RPM_VERSION_STRING | cut -f 2 -d '.' `
            RPM_PATCH_STRING=`echo $RPM_VERSION_STRING | cut -f 3 -d '.' |sed 's/[a-zA-Z]//g'`

            if [ -n "$RPM_MAJOR_STRING" ] ; then
                RPM_MAJOR=`expr $RPM_MAJOR_STRING `
            else
                RPM_MAJOR=0
            fi

            if [ -n "$RPM_MINOR_STRING" ]; then
                RPM_MINOR=`expr $RPM_MINOR_STRING `
            else
                RPM_MINOR=0
            fi

            if [ -n "$RPM_PATCH_STRING" ]; then
                RPM_PATCH=`expr $RPM_PATCH_STRING `
            else
                RPM_PATCH=0
            fi

            if [ "$RPM_MAJOR" != "$RPM_REQUIRED_MAJOR" ] ; then
                return 2
            fi

            if [ "$RPM_MINOR" != "$RPM_REQUIRED_MINOR" ] ; then
                return 2
            fi

            if [ "$RPM_PATCH" != "$RPM_REQUIRED_PATCH" ] ; then
                return 2
            fi

            if [ "$RPM_PATCH" != "$RPM_REQUIRED_PATCH" ] ; then
                return 3
            fi

            if [ ! -f "$REQ_PKGS_LIST" ]; then
                echo >&2
                echo "This installation seem to be corrupt, the file $REQ_PKGS_LIST is missing" >&2
                echo "in the required path" >&2
#                echo "contact technical support." >&2
                echo >&2
                IS_SANITY_OK=no
            else
                #TODO: Need to write a more simple form of the below statement without perl as 
                #perl may not be present in the users box
                #Check if the required list of packages are present in the box
                MISSING_PKG_CNT=`cat $REQ_PKGS_LIST | perl -e ' while (<>){chop;print $_, " "};'|xargs rpm -q |grep "is not installed"|wc -l`
                
                if [ -n "$MISSING_PKG_CNT" ] ; then
                    RESULT=`expr $MISSING_PKG_CNT `
                    if [ $RESULT -gt 0 ] ; then
                        echo >&2
                        echo "WARNING : This installation has found that some of the required package is missing" >&2
#                        echo "contact technical support." >&2
                        echo >&2
                        IS_SANITY_OK=no
                    fi
                fi
            fi
        fi
        echo "Required packages Check: OK"
}

check_disk(){

    #Check for NFS mounts (Warn the user that it might be harmfull for CEE)
    echo "Checking Disk Space." >&2
    MNT_POINT_CNT=$( expr `df -h|cut -d ' ' -f1|grep :|wc -l` )
    RESULT="$?"
    if [ "$RESULT" != "0" -o $MNT_POINT_CNT -ge 1 ] ; then
        echo >&2
        echo "WARNING: Identified one NFS mount point. This may cause problems while installing CEE. For more information, see the readme.html file."
        echo >&2
        IS_SANITY_OK=no
        
    fi
    echo "Disk Check: OK"
}

check_ports(){
    # ports to be verified
    ports='1099 1100 11100 8080 2900 2401 5999 26000'
    # service names as per above ports
    service="Anzu Jboss Reporting Apache ETL ccvs(pserver) cvsupd Indexer"

    # counter for the port index
    port_index=1
    
    is_port_used=true

    # use sudo if you want i.e. sudo /bin/netstat
    netstat -tln | grep -vE '^Active|Proto' | while read LINE
    do
        # get active port name and use : as delimiter
        t=$(echo $LINE | awk '{ print $4}' | cut -d: -f2)

        [ "$t" == "" ] && t=-1 || :

        # get service name from $services and : as delimiter
        sname=$(echo $service | cut -d' ' -f$port_index)

        sstatus="$sname: No"
        # now compare port
        for i in $ports
        do
            if [ $i -eq $t ]; then
                sstatus="$sname: Ok"
                is_port_used=false
            fi
        done
        if [ "$is_port_used" == "false" ]; then 
            echo >&2
            echo "ERROR: Port $t is in use, CEE needs this port for installation." >&2
            echo >&2
            exit 1
            IS_SANITY_OK=no
        fi

        port_index=$( expr $port_index + 1 )
    done
}


#main
#
# Interpret script parameters
while test $# -gt 0; do
    case "$1" in
    -*=*) optarg=`echo "$1" | sed 's/[-_a-zA-Z0-9]*=//'` ;;
    *) optarg= ;;
    esac

    case "$1" in
    -v=* | --version=*)
        echo Version $VERSION
        exit 0

    ;;
    -h | --help)
        usage
    exit 0
    ;;

    * )
        echo Invalid argument "$1"
    usage
        exit 1
        ;;
    esac
    shift
done

main



